<h1 align="center">
  <br>
  <a href="https://github.com/jackson147/Red-DiscordBot"><img src="https://i.imgur.com/VwLWOIy.png" alt="Red - Discord Bot"></a>
  <br>
  Sausage Discord Bot
  <br>
</h1>

<p align="center">
  <a href="https://pypi.org/project/sausage-bot/">
     <img alt="PyPI" src="https://img.shields.io/pypi/v/sausage-bot">
  </a>
  <a href="https://www.python.org/downloads/">
    <img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/sausage-bot">
  </a>
  <a href="https://github.com/Rapptz/discord.py/">
     <img src="https://img.shields.io/badge/discord-py-blue.svg" alt="discord.py">
  </a>
  <a href="https://www.patreon.com/Red_Devs">
    <img src="https://img.shields.io/badge/Support-Red!-red.svg" alt="Support Red on Patreon!">
  </a>
</p>

<p align="center">
  <a href="#overview">Overview</a>
  •
  <a href="http://red-discordbot.readthedocs.io/en/stable/index.html">Red-DiscordBot</a>
  •
  <a href="#license">License</a>
</p>

# Overview

This bot is to service a small community. It has been forked from [Red-DiscordBot](https://github.com/Cog-Creators/Red-DiscordBot).
Please visit their page for more information and installation instructions.

Please also consider contributing to the Red Patreon using the badge above.

# License

Released under the [GNU GPL v3](https://www.gnu.org/licenses/gpl-3.0.en.html) license.

Sausage is named after the main character (the leek spray) of "Overwatch", a video game by
[Blizzard](https://www.blizzard.com/en-gb/).

Background of Artwork created by [Sinlaire](https://sinlaire.deviantart.com/) on Deviant Art for the Red Discord
Bot Project.
OG artwork of the Leek is created by [Blizzard](https://www.blizzard.com/en-gb/).